@@ -2,10 +2,7 @@
 
   """
 
-import json
-
-from src.githubdata.funcs import get_data_from_github
-from src.githubdata.main import get_github_token_pathes
+from src.githubdata.main import get_data_from_github
 from src.githubdata.main import GithubData
 
 
@@ -13,10 +10,6 @@ from src.githubdata.main import GithubData
 u = 'https://github.com/imahdimir/d-TSETMC_ID-2-FirmTicker'
 df = get_data_from_github(u)
 
-## test get_github_token_pathes()
-fp = get_github_token_pathes()
-print(fp)
-
 ## clone a public repo
 u = 'https://github.com/imahdimir/d-TSETMC_ID-2-FirmTicker'
 repo = GithubData(u)
@@ -30,13 +23,6 @@ u = 'https://github.com/imahdimir/test-public'
 repo = GithubData(u)
 repo.overwriting_clone()
 
-##
-js = repo.meta
-##
-js['desc'] = 'test'
-with open(repo.meta_fp , 'w') as fi :
-    json.dump(js , fi , indent = 4)
-
 ##
 msg = 'test commit'
 repo.commit_and_push(msg)
@@ -44,7 +30,7 @@ repo.commit_and_push(msg)
 ##
 repo.rmdir()
 
-##
+## clone a private repo and commit back
 ur = 'https://github.com/imahdimir/test-private'
 rp = GithubData(ur)
 rp.overwriting_clone()
@@ -56,5 +42,3 @@ rp.overwriting_clone()
 rp.commit_and_push('test commit')
 
 ##
-
-##
